aboutsummaryrefslogtreecommitdiffstats
path: root/prototypes/workbench/manage.py
diff options
context:
space:
mode:
authoreunhhu <[email protected]>2026-10-05 09:19:32 +0100
committereunhhu <[email protected]>2026-10-05 09:19:32 +0100
commit2654f58ae6a7d0fcaf356b0f4cd69038b3eaf00c (patch)
treee91946d647d8bacfc0aa6d2b569fd7019a41e4a2 /prototypes/workbench/manage.py
parent1ef9dd24773058f766ad80ffc7a59295fc44c92d (diff)
downloadpure-2654f58ae6a7d0fcaf356b0f4cd69038b3eaf00c.tar.gz
pure-2654f58ae6a7d0fcaf356b0f4cd69038b3eaf00c.zip
Measure 021: BFS 190 to 90 ms over HTTP against C's 9.1, short of C; Pure's forms by hand beat C only packed, narrow and read ahead (123)
Diffstat (limited to 'prototypes/workbench/manage.py')
0 files changed, 0 insertions, 0 deletions